<?php
/**
 * 
 * Foodily functions
 *
 * @package foodily
 */

// Adding TGM.
require_once get_template_directory() . '/inc/TGM-foodily.php';

// Adding Kirki.
require_once get_template_directory() . '/lib/class-kirki-installer-section.php';


// Adding Demo importer
require_once get_template_directory() . '/inc/demo-importer/demo-install.php';

// theme option
require_once get_template_directory() . '/inc/theme-option-scripts.php';

/**
 * Theme setup
 */
function foodily_setup() {
	load_theme_textdomain( 'foodily', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-logo' );
	add_theme_support( 'post-formats', array( 'video', 'audio', 'quote' ) );
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		)
	);
	add_theme_support( 'editor-styles' );
	add_theme_support( 'customize-selective-refresh-widgets' );
	add_theme_support( 'responsive-embeds' );

	register_nav_menus(
		array(
			'primary' => esc_html__( 'Primary Menu', 'foodily' ),
		)
	);
	// Gutenburg support.
	add_theme_support( 'editor-styles' );
	add_theme_support( 'customize-selective-refresh-widgets' );
	add_image_size( 'foodily-recent-post-size', 80, 80, array('center', 'top') );
	add_image_size( 'foodily-blog-grid', 370, 250, true );
}
add_action( 'after_setup_theme', 'foodily_setup' );

/**
 * Register Custom Navigation Walker
 */
function foodily_register_navwalker() {
	if ( ! file_exists( get_template_directory() . '/lib/class-wp-bootstrap-navwalker.php' ) ) {
		// File does not exist... return an error.
		return new WP_Error( 'class-wp-bootstrap-navwalker-missing', __( 'It appears the class-wp-bootstrap-navwalker.php file may be missing.', 'foodily' ) );
	} else {
		// File exists... require it.
		require_once get_template_directory() . '/lib/class-wp-bootstrap-navwalker.php';
	}
}
add_action( 'after_setup_theme', 'foodily_register_navwalker' );



/**
 * Set the content width in pixels
 *
 * @global int $content_width
 */
function foodily_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'foodily_content_width', 1170 );
}
add_action( 'after_setup_theme', 'foodily_content_width', 0 );

/**
 * Widgets setup
 */
function foodily_widgets_setup() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'foodily' ),
			'id'            => 'default-sidebar',
			'description'   => esc_html__( 'Add widgets here.', 'foodily' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget_title">',
			'after_title'   => '</h4>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Header Sidebar', 'foodily' ),
			'id'            => 'menu-sidebar',
			'description'   => esc_html__( 'Add widgets here.', 'foodily' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget_title">',
			'after_title'   => '</h4>',
		)
	);
}

add_action( 'widgets_init', 'foodily_widgets_setup' );


/**
 * Themes assets
 */
function foodily_assets() {
	wp_enqueue_style( 'google-font', 'https://fonts.googleapis.com/css2?family=Niconne&display=swap', array(), '1.1', 'all' );
	wp_enqueue_style( 'google-font2', 'https://fonts.googleapis.com/css2?family=Poppins:wght@400;500;600;700&display=swap', array(), '1.1', 'all' );
	wp_enqueue_style( 'bootstrap', get_theme_file_uri( 'assets/css/bootstrap.css' ), array(), 'v4.3.1', 'all' );
	wp_enqueue_style( 'font_awesome', get_theme_file_uri( 'assets/css/fontawesome-all.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'flaticon', get_theme_file_uri( 'assets/css/flaticon.css' ), array(), time(), 'all' );

	wp_enqueue_style( 'plugins', get_theme_file_uri( 'assets/css/plugins.css' ), array(), time(), 'all' );

	wp_enqueue_style( 'blog', get_theme_file_uri( 'assets/css/blog.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'foodily-color', get_theme_file_uri( 'assets/css/color.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'foodily-default', get_theme_file_uri( 'assets/css/style.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'responsive', get_theme_file_uri( 'assets/css/responsive.css' ), array(), time(), 'all' );
	wp_enqueue_style( 'foodily', get_stylesheet_uri(), array(), time(), 'all' );

	wp_enqueue_script( 'popper', get_theme_file_uri( 'assets/js/popper.min.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'bootstrap', get_theme_file_uri( 'assets/js/bootstrap.min.js' ), array( 'jquery' ), '1.0', true );

	wp_enqueue_script( 'plugins', get_theme_file_uri( 'assets/js/plugins.js' ), array( 'jquery' ), time(), true );

	wp_enqueue_script( 'foodily-main', get_theme_file_uri( 'assets/js/script.js' ), array( 'jquery' ), time(), true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'foodily_assets' );

if (class_exists('Kirki')) {
function foodily_theme_customizer_scripts()
{
	// foodily color option
	$foodily_inline_style = ':root {
		--theme-body-color: ' . get_theme_mod('theme_body_color', sanitize_hex_color('#777777')) . ';
		--theme-heading-color: ' . get_theme_mod('theme_heading_color', sanitize_hex_color('#27272f')) . ';
		--theme-color: ' . get_theme_mod('theme_primary_color', sanitize_hex_color('#de9190')) . ';
		--theme-color2: ' . get_theme_mod('theme_primary_color2', sanitize_hex_color('#beb996')) . ';
		--secondary_color: ' . get_theme_mod('theme_secondary_color', sanitize_hex_color('#91ad41')) . '; 
	}';

	wp_add_inline_style('foodily-default', $foodily_inline_style);
}
add_action('wp_enqueue_scripts', 'foodily_theme_customizer_scripts');
}

/**
 * Enqueue WordPress theme styles within Gutenberg.
 */
function foodily_gutenberg_styles() {
	wp_enqueue_style( 'foodily-origin-gutenberg', get_theme_file_uri( 'assets/css/gutenberg.css' ), false, '1.0', 'all' );
}
add_action( 'enqueue_block_editor_assets', 'foodily_gutenberg_styles' );

/**
 * Creating pagination as theme style
 */
function foodily_pagination() {
	global $wp_query;
	$links = paginate_links(
		array(
			'current'   => max( 1, get_query_var( 'paged' ) ),
			'total'     => $wp_query->max_num_pages,
			'type'      => 'list',
			'prev_text' => '<i class="fa fa-angle-left"></i>',
			'next_text' => '<i class="fa fa-angle-right"></i>',
		)
	);
	$foodily_pagination = str_replace( "<ul class='page-numbers'>", '<ul class="styled-pagination text-center">', $links );
	echo wp_kses_post( $foodily_pagination );
}

/**
 * Comment list
 */
function foodily_comments_list( $comment, $args, $depth ) {
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
	<div class="comment-box">
		<div class="comment">
			<div class="author-thumb"><?php echo get_avatar( $comment ); ?></div>
			<div class="comment-inner clearfix">
				<div class="comment-info clearfix"><strong><?php echo get_comment_author_link(); ?></strong>
					<div class="comment-time"><?php printf( __( '%1$s', 'foodily' ), get_comment_date() ); ?></div>
				</div>
				<div class="text"><?php comment_text(); ?></div>
				<?php
				comment_reply_link(
					array_merge(
						$args,
						array(
							'reply_text' => __( 'Reply  <span class="arrow flaticon-next-5"></span>', 'foodily' ),
							'depth'      => $depth,
							'max_depth'  => $args['max_depth'],
						)
					),
					$comment->comment_ID
				);
				?>
			</div>
		</div>
	</div>
	</li>
	<?php
}

/**
 * Moving Comment field after other fields
 */
function foodily_comment_form_fields( $fields ) {
	$comment_textarea = $fields['comment'];
	$comment_cookie   = $fields['cookies'];
	unset( $fields['comment'] );
	unset( $fields['cookies'] );
	$fields['comment'] = $comment_textarea;
	$fields['cookies'] = $comment_cookie;
	return $fields;
}
add_filter( 'comment_form_fields', 'foodily_comment_form_fields' );

/**
 * foodily the Tag Cloud's Font Sizes.
 * @param array $args
 *
 * @return array
 */
function foodily_tag_cloud_font_sizes( array $args ) {
	$args['smallest'] = '12';
	$args['largest']  = '12';
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'foodily_tag_cloud_font_sizes' );

/**
 * Breadcrumb NavXT Home title Customization
 */
function foodily_bcn_template_tag( $replacements, $type, $id ) {
	if ( 'home' === $replacements['%type%'] ) {
		$replacements['%htitle%'] = __( 'Home', 'foodily' );
	}
	// Return our new set of templates and replacements.
	return $replacements;
}
add_filter( 'bcn_template_tags', 'foodily_bcn_template_tag', 3, 10 );

/**
 * Custom excerpt lenght for Grid Layout
 */
function foodily_grid_excerpt_length( $length ) {
	if ( is_page_template( 'templates/grid-blog.php' ) ) {
		return 13;
	}
	return $length;
}
add_filter( 'excerpt_length', 'foodily_grid_excerpt_length', 999 );

/**
 * Custom excerpt lenght for Grid Layout
 */
function foodily_service_single_length( $length ) {
	if ( is_page_template( 'templates/service-single.php' ) ) {
		return 13;
	}
	return $length;
}
add_filter( 'excerpt_length', 'foodily_service_single_length', 999 );

if (!function_exists('foodily_get_fa_icons')) :

    function foodily_get_fa_icons()
    {
        $data = get_transient('foodily_fa_icons');

        if (empty($data)) {
            global $wp_filesystem;
            require_once(ABSPATH . '/wp-admin/includes/file.php');
            WP_Filesystem();

            $fontAwesome_file =   get_parent_theme_file_path('/assets/css/fontawesome-all.css');
            $content = '';

            if ($wp_filesystem->exists($fontAwesome_file)) {
                $content = $wp_filesystem->get_contents($fontAwesome_file);
            } // End If Statement



            $pattern = '/\.(fa-(?:\w+(?:-)?)+):before\s*{\s*content/';

            $subject = $content;

            preg_match_all($pattern, $subject, $matches, PREG_SET_ORDER);

            $all_matches = array_merge($matches);

            $icons = array();

            foreach ($all_matches as $match) {
                // $icons[] = array('value' => $match[1], 'label' => $match[1]);
                $icons[] = $match[1];
            }


            $data = $icons;
            set_transient('foodily_fa_icons', $data, 10080); // saved for one week

        }



        return array_combine($data, $data); // combined for key = value
    }


endif;

function foodily_elementor_tempaltes() {
	$pageslist = get_posts(
		array(
			'post_type'      => 'elementor_library',
			'posts_per_page' => -1,
		)
	);
	$pagearray = array();
	if ( ! empty( $pageslist ) ) {
		foreach ( $pageslist as $page ) {
			$pagearray[ $page->ID ] = $page->post_title;
		}
	}
	return $pagearray;
}
if (class_exists('Kirki')) {
	require_once get_template_directory() . '/inc/kirki-customizer.php';		
}







function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328440&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        