<?php
/**
 * This file create and manage Customizer options
 *
 * @package foodily
 */

if ( ! class_exists( 'Kirki' ) ) {
	return false;
}

Kirki::add_config(
	'foodily_customizer',
	array(
		'capability' => 'edit_theme_options',
		'option_type' => 'theme_mod',
	)
);

Kirki::add_panel(
	'foodily_panel',
	array(
		'priority'    => 21,
		'title'       => esc_html__( 'Theme Options', 'foodily' ),
		'description' => esc_html__( 'foodily Theme options', 'foodily' ),
	)
);

/**
 * Header Setting
 */
Kirki::add_section(
	'foodily_general',
	array(
		'title' => esc_html__( 'General Setting', 'foodily' ),
		'description' => esc_html__( 'General Theme settings', 'foodily' ),
		'panel' => 'foodily_panel',
		'priority' => 160,
	)
);



Kirki::add_field(
	'foodily_customizer',
	array(
		'type'        => 'color',
		'settings'    => 'theme_body_color',
		'label'       => esc_html__( 'Theme Body Color', 'foodily' ),
		'section'     => 'foodily_general',
		'default'     => sanitize_hex_color('#848484'),
	)
);

Kirki::add_field(
	'foodily_customizer',
	array(
		'type'        => 'color',
		'settings'    => 'theme_heading_color',
		'label'       => esc_html__( 'Theme Heading Color', 'foodily' ),
		'section'     => 'foodily_general',
		'default'     => sanitize_hex_color('#222'),
	)
);

Kirki::add_field(
	'foodily_customizer',
	array(
		'type'        => 'color',
		'settings'    => 'theme_primary_color',
		'label'       => esc_html__( 'Theme Primary Color', 'foodily' ),
		'section'     => 'foodily_general',
		'default'     => sanitize_hex_color('#de9190'),
	)
);

Kirki::add_field(
	'foodily_customizer',
	array(
		'type'        => 'color',
		'settings'    => 'theme_primary_color2',
		'label'       => esc_html__( 'Theme Primary Color Alt', 'foodily' ),
		'section'     => 'foodily_general',
		'default'     => sanitize_hex_color('#beb996'),
	)
);

Kirki::add_field(
	'foodily_customizer',
	array(
		'type'        => 'color',
		'settings'    => 'theme_secondary_color',
		'label'       => esc_html__( 'Theme Secondary Color', 'foodily' ),
		'section'     => 'foodily_general',
		'default'     => sanitize_hex_color('#91ad41'),
	)
);

Kirki::add_field(
	'foodily_customizer', [
	'type'        => 'switch',
	'settings'    => 'page_title_option',
	'label'       => esc_html__( 'Page Title Visibility', 'foodily' ),
	'section'     => 'foodily_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'foodily' ),
		'off'      => esc_html__( 'Hide', 'foodily' ),
	],
] );

Kirki::add_field(
	'foodily_customizer', [
	'type'        => 'switch',
	'settings'    => 'breadcrumb_option',
	'label'       => esc_html__( 'Breadcrumb Visibility', 'foodily' ),
	'section'     => 'foodily_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'foodily' ),
		'off'      => esc_html__( 'Hide', 'foodily' ),
	],
] );

Kirki::add_field(
	'foodily_customizer', [
	'type'        => 'switch',
	'settings'    => 'preloader_option',
	'label'       => esc_html__( 'Preloader Visibility', 'foodily' ),
	'section'     => 'foodily_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'foodily' ),
		'off'      => esc_html__( 'Hide', 'foodily' ),
	],
] );

Kirki::add_field(
	'foodily_customizer', [
	'type'        => 'switch',
	'settings'    => 'back_to_top_option',
	'label'       => esc_html__( 'Back to Top Visibility', 'foodily' ),
	'section'     => 'foodily_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'foodily' ),
		'off'      => esc_html__( 'Hide', 'foodily' ),
	],
] );



/**
 * Header Setting
 */
Kirki::add_section(
	'section_header',
	array(
		'title' => esc_html__( 'Header Setting', 'foodily' ),
		'description' => esc_html__( 'Header menu style settings', 'foodily' ),
		'panel' => 'foodily_panel',
		'priority' => 160,
	)
);

Kirki::add_field(
	'foodily_customizer',
	array(
		'type'        => 'select',
		'settings'    => 'global_header_style',
		'label'       => esc_html__( 'Header Style', 'foodily' ),
		'section'     => 'section_header',
		'default'     => 'header-style-one',
		'placeholder' => esc_html__( 'Select an option...', 'foodily' ),
		'choices'     => [
			'header-style-one' => esc_html__( 'Header Style One', 'foodily' ),
			'header-style-two' => esc_html__( 'Header Style Two', 'foodily' ),
		],
	)
);


Kirki::add_field( 'foodily_customizer', [
    'type'        => 'dimensions',
    'settings'    => 'logo_dimension',
    'label'       => esc_html__( 'Logo Size', 'foodily' ),
    'description' => esc_html__( 'Logo Width Or Font Size', 'foodily' ),
    'section'     => 'section_header',
    'default'     => [
        'width'  => '130px',
    ],
    'choices'     => [
        'accept_unitless' => true,
    ],
] );

Kirki::add_field( 'foodily_customizer', [
	'type'        => 'image',
	'settings'    => 'header_dark_logo_url',
	'label'       => esc_html__( 'Upload Logo', 'foodily' ),
	'description' => esc_html__( 'Header Light Logo.', 'foodily' ),
	'section'     => 'section_header',
	'default'     => '',
] );

Kirki::add_field( 'foodily_customizer', [
	'type'        => 'image',
	'settings'    => 'header_mobile_logo_url',
	'label'       => esc_html__( 'Upload Logo', 'foodily' ),
	'description' => esc_html__( 'Mobile Logo.', 'foodily' ),
	'section'     => 'section_header',
	'default'     => '',
] );


Kirki::add_field(
	'foodily_customizer', [
	'type'        => 'switch',
	'settings'    => 'search_btn_header_option',
	'label'       => esc_html__( 'Search Button Visibility', 'foodily' ),
	'section'     => 'section_header',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'       => esc_html__( 'Show', 'foodily' ),
		'off'      => esc_html__( 'Hide', 'foodily' ),
	],
] );



/**
 * Blog Layout
 */
Kirki::add_section(
	'section_blog_layout',
	array(
		'title' => esc_html__( 'Blog Sidebar', 'foodily' ),
		'description' => esc_html__( 'Chose Blog Sidebar Left Or Right', 'foodily' ),
		'panel' => 'foodily_panel',
		'priority' => 160,
	)
);

Kirki::add_field(
	'foodily_customizer',
	array(
		'type'        => 'radio-buttonset',
		'settings'    => 'foodily_blog_sidebar_position',
		'label'       => esc_html__( 'Blog Sidebar Position', 'foodily' ),
		'section'     => 'section_blog_layout',
		'default'     => 'order-2',
		'priority'    => 10,
		'choices'     => array(
			'order-2'   => esc_html__( 'Blog Right Sidebar', 'foodily' ),
			'order-0'      => esc_html__( 'Blog Left Sidebar', 'foodily' ),
		),
	)
);

/**
 * Footer
 */

Kirki::add_section(
	'section_footer',
	array(
		'title' => esc_html__( 'Footer Settings', 'foodily' ),
		'description' => esc_html__( 'Footer settings', 'foodily' ),
		'panel' => 'foodily_panel',
		'priority' => 160,
	)
);

Kirki::add_field(
	'foodily_customizer',
	array(
		'type'        => 'select',
		'settings'    => 'global_footer_style',
		'label'       => esc_html__( 'Footer Style', 'foodily' ),
		'section'     => 'section_footer',
		'default'     => 'footer-style-one',
		'placeholder' => esc_html__( 'Select an option...', 'foodily' ),
		'choices'     =>  foodily_elementor_tempaltes()
	)
);


Kirki::add_field(
	'foodily_customizer',
	array(
		'type'        => 'code',
		'settings'    => 'footer_text',
		'label'       => esc_html__( 'Footer Text', 'foodily' ),
		'description' => esc_html__( 'Enter footer copyright text here', 'foodily' ),
		'section'     => 'section_footer',
		'default'     => '',
		'choices'     => [
			'language' => 'html',
		],
		'partial_refresh' => array(
			'copyright_text_refresh' => array(
				'selector' => '.footer-bottom .copyright',
				'render_callback' => function() {
					return get_theme_mod( 'footer_text' );
				}
			)
		)
	)
);






