<?php

/**
 * foodily functions for getting inline styles from theme customizer
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package foodily
 */




if ( ! function_exists( 'foodily_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function foodily_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( ' %s', 'post date', 'foodily' ),
			'' . $time_string . ''
		);

		echo '' . $posted_on . '';

	}
endif;

if ( ! function_exists( 'foodily_category_list' ) ) :
	function foodily_category_list() {
		if ( 'post' === get_post_type() ) {
			$category_list = get_the_category_list();
			if ( $category_list ) {
				printf( $category_list ); // WPCS: XSS OK.
			}
		}
	}
endif;

if ( ! function_exists( 'foodily_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function foodily_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( '%s', 'post author', 'foodily' ),
			'' . '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>'
		);
		printf( $byline );
	}
endif;
if ( ! function_exists( 'foodily_comments_count' ) ) :

	function foodily_comments_count() {
		if ( get_comments_number( get_the_ID() ) == 0 ) {
			$comments_count = '<a href="' . esc_url( get_permalink() ) . '" >' . get_comments_number( get_the_ID() ) . ' Comments' . '</a>';
		} elseif ( get_comments_number( get_the_ID() ) > 1 ) {
			$comments_count = '<a href="' . esc_url( get_permalink() ) . '" >' . get_comments_number( get_the_ID() ) . ' Comments' . '</a>';
		} else {
			$comments_count = '<a href="' . esc_url( get_permalink() ) . '#comments" >' . get_comments_number( get_the_ID() ) . ' Comment' . '</a>';
		}
		echo sprintf( esc_html( '%s' ), $comments_count ); // WPCS: XSS OK.
	}

endif;









